@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: ohbci.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: ohbci.c,v 1.13 2005/09/29 03:21:55 aquamaniac Exp $
+    cvs         : $Id: ohbci.c 979 2006-02-04 01:47:12Z aquamaniac $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -117,13 +117,13 @@ int GWEN_CryptTokenOHBCI_Plugin_CheckToken(GWEN_PLUGIN *pl,
   p=GWEN_Buffer_GetStart(name);
   if (access(p, F_OK)) {
     DBG_ERROR(GWEN_LOGDOMAIN, "File does not exist");
-    GWEN_WaitCallback_Log(GWEN_LoggerLevelInfo, "File does not exist");
+    GWEN_WaitCallback_Log(GWEN_LoggerLevel_Info, "File does not exist");
     return GWEN_ERROR_CT_BAD_NAME;
   }
 
   if (access(p, R_OK | W_OK)) {
     DBG_ERROR(GWEN_LOGDOMAIN, "File exists but I have no writes on it");
-    GWEN_WaitCallback_Log(GWEN_LoggerLevelInfo,
+    GWEN_WaitCallback_Log(GWEN_LoggerLevel_Info,
                           "File exists but I have no writes on it");
     return GWEN_ERROR_CT_IO_ERROR;
   }
@@ -132,7 +132,7 @@ int GWEN_CryptTokenOHBCI_Plugin_CheckToken(GWEN_PLUGIN *pl,
   if (!f) {
     DBG_ERROR(GWEN_LOGDOMAIN,
               "File exists, I have all rights but still can't open it");
-    GWEN_WaitCallback_Log(GWEN_LoggerLevelNotice,
+    GWEN_WaitCallback_Log(GWEN_LoggerLevel_Notice,
                           "File exists, I have all rights but "
                           "still can't open it");
     return GWEN_ERROR_CT_IO_ERROR;
@@ -142,14 +142,14 @@ int GWEN_CryptTokenOHBCI_Plugin_CheckToken(GWEN_PLUGIN *pl,
   fclose(f);
   if (rv!=1) {
     DBG_INFO(GWEN_LOGDOMAIN, "This seems not to be an OpenHBCI keyfile");
-    GWEN_WaitCallback_Log(GWEN_LoggerLevelInfo,
+    GWEN_WaitCallback_Log(GWEN_LoggerLevel_Info,
                           "This seems not to be an OpenHBCI keyfile");
     return GWEN_ERROR_CT_NOT_SUPPORTED;
   }
 
   if (rv!=1) {
     DBG_INFO(GWEN_LOGDOMAIN, "This seems not to be an OpenHBCI keyfile (bad size)");
-    GWEN_WaitCallback_Log(GWEN_LoggerLevelNotice,
+    GWEN_WaitCallback_Log(GWEN_LoggerLevel_Notice,
                           "This seems not to be an OpenHBCI keyfile "
                           "(bad size)");
     return GWEN_ERROR_CT_NOT_SUPPORTED;
@@ -158,14 +158,14 @@ int GWEN_CryptTokenOHBCI_Plugin_CheckToken(GWEN_PLUGIN *pl,
   if ((unsigned char)(buffer[0])==GWEN_CRYPTTOKEN_OHBCI_TAG_MEDIUM1) {
     DBG_INFO(GWEN_LOGDOMAIN,
              "Old OpenHBCI file detected");
-    GWEN_WaitCallback_Log(GWEN_LoggerLevelNotice,
+    GWEN_WaitCallback_Log(GWEN_LoggerLevel_Notice,
                           "Old OpenHBCI file detected");
     return 0;
   }
   else if ((unsigned char)(buffer[0])==GWEN_CRYPTTOKEN_OHBCI_TAG_MEDIUM2) {
     DBG_INFO(GWEN_LOGDOMAIN,
              "OpenHBCI file (<1.6) detected");
-    GWEN_WaitCallback_Log(GWEN_LoggerLevelNotice,
+    GWEN_WaitCallback_Log(GWEN_LoggerLevel_Notice,
              "OpenHBCI file (<1.6) detected");
     return 0;
   }
@@ -176,7 +176,7 @@ int GWEN_CryptTokenOHBCI_Plugin_CheckToken(GWEN_PLUGIN *pl,
                 strlen(GWEN_CRYPTTOKEN_OHBCI_NAME))==0) {
       DBG_INFO(GWEN_LOGDOMAIN,
                "New OpenHBCI file (>=1.6) detected");
-      GWEN_WaitCallback_Log(GWEN_LoggerLevelNotice,
+      GWEN_WaitCallback_Log(GWEN_LoggerLevel_Notice,
                             "New OpenHBCI file (>=1.6) detected");
       return 0;
     }
@@ -184,7 +184,7 @@ int GWEN_CryptTokenOHBCI_Plugin_CheckToken(GWEN_PLUGIN *pl,
 
   DBG_INFO(GWEN_LOGDOMAIN,
            "This seems not to be an OpenHBCI keyfile");
-  GWEN_WaitCallback_Log(GWEN_LoggerLevelNotice,
+  GWEN_WaitCallback_Log(GWEN_LoggerLevel_Notice,
                         "This seems not to be an OpenHBCI keyfile");
   return GWEN_ERROR_CT_NOT_SUPPORTED;
 }
@@ -244,23 +244,21 @@ int GWEN_CryptTokenOHBCI__DecryptFile(GWEN_CRYPTTOKEN *ct,
   GWEN_CRYPTTOKEN_OHBCI *lct;
   GWEN_CRYPTKEY *key;
   GWEN_ERRORCODE err;
-  unsigned char password_unsigned[64];
   char password[64];
   GWEN_BUFFER *rawbuf;
   int rv;
+  GWEN_PLUGIN_MANAGER *pm;
+  unsigned int pinLength=0;
 
   assert(ct);
   lct=GWEN_INHERIT_GETDATA(GWEN_CRYPTTOKEN, GWEN_CRYPTTOKEN_OHBCI, ct);
   assert(lct);
 
-  if (lct->passWordIsSet==0) {
-    GWEN_PLUGIN_MANAGER *pm;
-    int mres;
-    unsigned int pinLength;
-    unsigned int k;
+  pm=GWEN_CryptToken_GetCryptManager(ct);
+  assert(pm);
 
-    pm=GWEN_CryptToken_GetCryptManager(ct);
-    assert(pm);
+  if (lct->passWordIsSet==0) {
+    int mres;
 
     /* create key from password */
     memset(lct->password, 0, sizeof(lct->password));
@@ -270,21 +268,15 @@ int GWEN_CryptTokenOHBCI__DecryptFile(GWEN_CRYPTTOKEN *ct,
 				  GWEN_CryptToken_PinType_Access,
 				  GWEN_CryptToken_PinEncoding_ASCII,
 				  (trynum?GWEN_CRYPTTOKEN_GETPIN_FLAGS_RETRY:0),
-				  password_unsigned,
-				  GWEN_CRYPTTOKEN_OHBCI_PINMINLENGTH,
-				  sizeof(password_unsigned)-1,
-				  &pinLength);
+                                  (unsigned char*)password,
+                                  GWEN_CRYPTTOKEN_OHBCI_PINMINLENGTH,
+				  sizeof(password)-1,
+                                  &pinLength);
     if (mres) {
       DBG_ERROR(GWEN_LOGDOMAIN, "Error asking for PIN, aborting");
       return mres;
     }
 
-    /* Convert the 'unsigned char' buffer to the 'char' buffer */
-    for (k=0; k < pinLength; ++k)
-      password[k] = password_unsigned[k];
-    password[k] = '\0';
-    memset(password_unsigned, '\0', pinLength);
-
     if (strlen(password)<GWEN_CRYPTTOKEN_OHBCI_PINMINLENGTH) {
       DBG_ERROR(GWEN_LOGDOMAIN,
                 "Your program returned a shorter PIN than instructed!");
@@ -295,7 +287,8 @@ int GWEN_CryptTokenOHBCI__DecryptFile(GWEN_CRYPTTOKEN *ct,
     if (lct->cryptoTag==GWEN_CRYPTTOKEN_OHBCI_TAG_CRYPT) {
       DBG_NOTICE(GWEN_LOGDOMAIN, "New OpenHBCI file detected");
       if (GWEN_CryptKey_FromPassword(password,
-                                     (unsigned char*)lct->password, sizeof(lct->password))) {
+                                     (unsigned char*)lct->password,
+                                     sizeof(lct->password))) {
 	DBG_ERROR(GWEN_LOGDOMAIN,
 		  "Could not create key data from password");
         return GWEN_ERROR_GENERIC;
@@ -365,6 +358,16 @@ int GWEN_CryptTokenOHBCI__DecryptFile(GWEN_CRYPTTOKEN *ct,
     DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
     GWEN_Buffer_free(rawbuf);
     GWEN_CryptKey_free(key);
+    if (pinLength)
+      GWEN_CryptManager_SetPinStatus(pm,
+				     ct,
+				     GWEN_CryptToken_PinType_Access,
+				     GWEN_CryptToken_PinEncoding_ASCII,
+				     (trynum
+				      ?GWEN_CRYPTTOKEN_GETPIN_FLAGS_RETRY:0),
+				     (unsigned char*)password,
+				     pinLength,
+				     0);
     memset(password, 0, sizeof(password));
     lct->passWordIsSet=0;
     return GWEN_ERROR_CT_BAD_PIN;
@@ -377,8 +380,18 @@ int GWEN_CryptTokenOHBCI__DecryptFile(GWEN_CRYPTTOKEN *ct,
     GWEN_Buffer_free(rawbuf);
     GWEN_CryptKey_free(key);
     /* TODO: Set Pin status */
-    memset(password, 0, sizeof(password));
     lct->passWordIsSet=0;
+    if (pinLength)
+      GWEN_CryptManager_SetPinStatus(pm,
+				     ct,
+				     GWEN_CryptToken_PinType_Access,
+				     GWEN_CryptToken_PinEncoding_ASCII,
+				     (trynum
+				      ?GWEN_CRYPTTOKEN_GETPIN_FLAGS_RETRY:0),
+				     (unsigned char*)password,
+				     pinLength,
+				     0);
+    memset(password, 0, sizeof(password));
     return GWEN_ERROR_CT_BAD_PIN;
   }
   GWEN_CryptKey_free(key);
@@ -391,13 +404,34 @@ int GWEN_CryptTokenOHBCI__DecryptFile(GWEN_CRYPTTOKEN *ct,
   if (rv) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     GWEN_Buffer_free(rawbuf);
-    /* TODO: Set Pin status */
+    /* Set Pin status */
+    if (pinLength)
+      GWEN_CryptManager_SetPinStatus(pm,
+				     ct,
+				     GWEN_CryptToken_PinType_Access,
+				     GWEN_CryptToken_PinEncoding_ASCII,
+				     (trynum
+				      ?GWEN_CRYPTTOKEN_GETPIN_FLAGS_RETRY:0),
+				     (unsigned char*)password,
+				     pinLength,
+				     0);
     memset(password, 0, sizeof(password));
     lct->passWordIsSet=0;
     return GWEN_ERROR_CT_BAD_PIN;
   }
   GWEN_Buffer_free(rawbuf);
-  /* TODO: Set Pin status */
+  /* Set Pin status */
+  if (pinLength)
+    GWEN_CryptManager_SetPinStatus(pm,
+				   ct,
+				   GWEN_CryptToken_PinType_Access,
+				   GWEN_CryptToken_PinEncoding_ASCII,
+				   (trynum
+				    ?GWEN_CRYPTTOKEN_GETPIN_FLAGS_RETRY:0),
+				   (unsigned char*)password,
+				   pinLength,
+				   1);
+  memset(password, 0, sizeof(password));
   return 0;
 }
 
@@ -473,7 +507,7 @@ int GWEN_CryptTokenOHBCI_Read(GWEN_CRYPTTOKEN *ct, int fd){
     if (i>GWEN_CRYPTTOKEN_OHBCI_MAX_PIN_TRY) {
       DBG_ERROR(GWEN_LOGDOMAIN,
 		"No valid PIN within %d tries, giving up", i);
-      GWEN_WaitCallback_Log(GWEN_LoggerLevelCritical,
+      GWEN_WaitCallback_Log(GWEN_LoggerLevel_Critical,
                             I18N("No valid PIN (tried too often), "
 				 "aborting."));
       GWEN_Buffer_free(fbuf);
@@ -507,7 +541,7 @@ int GWEN_CryptTokenOHBCI_Read(GWEN_CRYPTTOKEN *ct, int fd){
         return rv;
       case GWEN_ERROR_CT_BAD_PIN:
         DBG_ERROR(GWEN_LOGDOMAIN, "Bad pin.");
-	GWEN_WaitCallback_Log(GWEN_LoggerLevelCritical,
+	GWEN_WaitCallback_Log(GWEN_LoggerLevel_Critical,
 			      I18N("Bad PIN, will try again"));
 	break;
 
@@ -726,6 +760,14 @@ void GWEN_CryptTokenOHBCI__DecodeKey(GWEN_CRYPTTOKEN *ct,
 			    p, l);
       break;
 
+    case GWEN_CRYPTTOKEN_OHBCI_TAG_KEY_LEN:
+      assert(p);
+      GWEN_DB_SetIntValue(node,
+                          GWEN_DB_FLAGS_OVERWRITE_VARS,
+                          "keyLength",
+                          atoi(p));
+      break;
+
     default:
       DBG_WARN(GWEN_LOGDOMAIN, "Unknown tag %02x", GWEN_TAG16_GetTagType(tlv));
       break;
@@ -824,7 +866,7 @@ int GWEN_CryptTokenOHBCI__Decode(GWEN_CRYPTTOKEN *ct, GWEN_BUFFER *dbuf) {
         DBG_WARN(GWEN_LOGDOMAIN,
                  "Keyfile version is higher than mine (%d).\n",
                  i);
-        GWEN_WaitCallback_Log(GWEN_LoggerLevelWarning,
+        GWEN_WaitCallback_Log(GWEN_LoggerLevel_Warning,
                               "This key file file has been created with a "
                               "newer library version.\n");
         free(p);
@@ -904,6 +946,18 @@ int GWEN_CryptTokenOHBCI__Decode(GWEN_CRYPTTOKEN *ct, GWEN_BUFFER *dbuf) {
       DBG_INFO(GWEN_LOGDOMAIN,
 	       "Ignoring temporary crypt keys");
       break;
+
+    case GWEN_CRYPTTOKEN_OHBCI_TAG_USER_PRIVAUTHKEY:
+      GWEN_CryptTokenOHBCI__DecodeKey(ct, tlv, dbKeys, "localAuthKey");
+      break;
+
+    case GWEN_CRYPTTOKEN_OHBCI_TAG_INST_PUBAUTHKEY:
+      GWEN_CryptTokenOHBCI__DecodeKey(ct, tlv, dbKeys, "remoteAuthKey");
+      break;
+
+    case GWEN_CRYPTTOKEN_OHBCI_TAG_HEADER:
+      /* ignore header here */
+      break;
     default:
       DBG_WARN(GWEN_LOGDOMAIN, "Unknown tag %02x",
 	       GWEN_TAG16_GetTagType(tlv));
@@ -926,7 +980,7 @@ int GWEN_CryptTokenOHBCI__Decode(GWEN_CRYPTTOKEN *ct, GWEN_BUFFER *dbuf) {
 
     GWEN_DB_SetIntValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
                         "data/public", 0);
-    key=GWEN_CryptKey_FromDb(dbKey);
+    key=GWEN_CryptKey_fromDb(dbKey);
     if (!key) {
       rv=-1;
       DBG_ERROR(GWEN_LOGDOMAIN, "Bad key format");
@@ -945,7 +999,7 @@ int GWEN_CryptTokenOHBCI__Decode(GWEN_CRYPTTOKEN *ct, GWEN_BUFFER *dbuf) {
 
     GWEN_DB_SetIntValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
                         "data/public", 0);
-    key=GWEN_CryptKey_FromDb(dbKey);
+    key=GWEN_CryptKey_fromDb(dbKey);
     if (!key) {
       rv=-1;
       DBG_ERROR(GWEN_LOGDOMAIN, "Bad key format");
@@ -964,7 +1018,7 @@ int GWEN_CryptTokenOHBCI__Decode(GWEN_CRYPTTOKEN *ct, GWEN_BUFFER *dbuf) {
 
     GWEN_DB_SetIntValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
                         "data/public", 1);
-    key=GWEN_CryptKey_FromDb(dbKey);
+    key=GWEN_CryptKey_fromDb(dbKey);
     if (!key) {
       rv=-1;
       DBG_ERROR(GWEN_LOGDOMAIN, "Bad key format");
@@ -985,7 +1039,7 @@ int GWEN_CryptTokenOHBCI__Decode(GWEN_CRYPTTOKEN *ct, GWEN_BUFFER *dbuf) {
 
     GWEN_DB_SetIntValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
                         "data/public", 1);
-    key=GWEN_CryptKey_FromDb(dbKey);
+    key=GWEN_CryptKey_fromDb(dbKey);
     if (!key) {
       rv=-1;
       DBG_ERROR(GWEN_LOGDOMAIN, "Bad key format");
@@ -998,10 +1052,48 @@ int GWEN_CryptTokenOHBCI__Decode(GWEN_CRYPTTOKEN *ct, GWEN_BUFFER *dbuf) {
     }
   }
 
+  /* local auth key */
+  dbKey=GWEN_DB_GetGroup(dbKeys, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
+                         "localAuthKey");
+  if (dbKey) {
+    GWEN_CRYPTKEY *key;
+
+    GWEN_DB_SetIntValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                        "data/public", 0);
+    key=GWEN_CryptKey_fromDb(dbKey);
+    if (!key) {
+      rv=-1;
+      DBG_ERROR(GWEN_LOGDOMAIN, "Bad key format");
+    }
+    else {
+      GWEN_CryptKey_SetStatus(key, GWEN_CRYPTTOKEN_KEYSTATUS_ACTIVE);
+      GWEN_CryptTokenFile_Context_SetLocalAuthKey(fct, key);
+    }
+  }
+
+  /* remote auth key */
+  dbKey=GWEN_DB_GetGroup(dbKeys, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
+                         "remoteAuthKey");
+  if (dbKey) {
+    GWEN_CRYPTKEY *key;
+
+    GWEN_DB_SetIntValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                        "data/public", 1);
+    key=GWEN_CryptKey_fromDb(dbKey);
+    if (!key) {
+      rv=-1;
+      DBG_ERROR(GWEN_LOGDOMAIN, "Bad key format");
+    }
+    else {
+      GWEN_CryptKey_SetStatus(key, GWEN_CRYPTTOKEN_KEYSTATUS_ACTIVE);
+      GWEN_CryptTokenFile_Context_SetRemoteAuthKey(fct, key);
+    }
+  }
+
   /* finalize user and file context */
   GWEN_CryptToken_User_SetId(user, 1);            /* only one user */
   GWEN_CryptToken_User_SetContextId(user, 1);     /* only one context */
-  GWEN_CryptToken_User_SetPeerId(user, peerId); /* only one user */
+  GWEN_CryptToken_User_SetPeerId(user, peerId);   /* only one user */
   GWEN_CryptTokenFile_Context_SetUser(fct, user);
 
   /* clear context list, add new context */
@@ -1092,7 +1184,7 @@ int GWEN_CryptTokenOHBCI__DecryptFile16(GWEN_CRYPTTOKEN *ct,
         DBG_WARN(GWEN_LOGDOMAIN,
                  "Keyfile version is higher than mine (%d).\n",
                  i);
-        GWEN_WaitCallback_Log(GWEN_LoggerLevelWarning,
+        GWEN_WaitCallback_Log(GWEN_LoggerLevel_Warning,
                               "This key file file has been created with a "
                               "newer library version.\n");
         free(p);
@@ -1162,7 +1254,7 @@ int GWEN_CryptTokenOHBCI__EncodeKey(const GWEN_CRYPTKEY *key,
     return 0;
   }
   dbKey=GWEN_DB_Group_new("key");
-  err=GWEN_CryptKey_ToDb(key, dbKey, wantPublic);
+  err=GWEN_CryptKey_toDb(key, dbKey, wantPublic);
   if (!GWEN_Error_IsOk(err)) {
     DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
     GWEN_DB_Group_free(dbKey);
@@ -1201,6 +1293,11 @@ int GWEN_CryptTokenOHBCI__EncodeKey(const GWEN_CRYPTKEY *key,
                              numbuf,
                              -1,
                              dbuf);
+  snprintf(numbuf, sizeof(numbuf), "%d", GWEN_CryptKey_GetKeyLength(key));
+  GWEN_TAG16_DirectlyToBuffer(GWEN_CRYPTTOKEN_OHBCI_TAG_KEY_LEN,
+                             numbuf,
+                             -1,
+                             dbuf);
 
   p=GWEN_DB_GetBinValue(dbKey, "data/e", 0, 0, 0, &bs);
   if (p && bs)
@@ -1391,6 +1488,23 @@ int GWEN_CryptTokenOHBCI_Encode(GWEN_CRYPTTOKEN *ct, GWEN_BUFFER *dbuf) {
   GWEN_TAG16_DirectlyToBuffer(GWEN_CRYPTTOKEN_OHBCI_TAG_REMOTE_SEQ,
 			      numbuf, -1, dbuf);
 
+  /* new in 1.7 */
+  key=GWEN_CryptTokenFile_Context_GetLocalAuthKey(fct);
+  if (GWEN_CryptTokenOHBCI__EncodeKey(key,
+                                      GWEN_CRYPTTOKEN_OHBCI_TAG_USER_PRIVAUTHKEY,
+                                      1, 0, dbuf)) {
+    DBG_ERROR(GWEN_LOGDOMAIN, "Could not encode key");
+    return -1;
+  }
+
+  key=GWEN_CryptTokenFile_Context_GetRemoteAuthKey(fct);
+  if (GWEN_CryptTokenOHBCI__EncodeKey(key,
+                                      GWEN_CRYPTTOKEN_OHBCI_TAG_INST_PUBAUTHKEY,
+				      0, 0, dbuf)) {
+    DBG_ERROR(GWEN_LOGDOMAIN, "Could not encode key");
+    return -1;
+  }
+
   return 0;
 }
 
