@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: tag16_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: tag16_p.h,v 1.1 2005/07/23 09:32:06 aquamaniac Exp $
+    cvs         : $Id: tag16_p.h 790 2005-07-23 09:32:08Z aquamaniac $
     begin       : Sun Jun 13 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
