@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: csv.c,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: csv.c,v 1.13 2005/08/23 06:24:09 aquamaniac Exp $
+ cvs         : $Id: csv.c 1020 2006-03-26 17:16:05Z aquamaniac $
  begin       : Thu Oct 30 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -560,7 +560,7 @@ GWEN_DBIO_CHECKFILE_RESULT GWEN_DBIO_CSV_CheckFile(GWEN_DBIO *dbio,
     DBG_ERROR(GWEN_LOGDOMAIN, "open(%s): %s",
               fname,
 	      strerror(errno));
-    return 0;
+    return GWEN_DBIO_CheckFileResultNotOk;
   }
   bio=GWEN_BufferedIO_File_new(fd);
   assert(bio);
