@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: olddb_p.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: olddb_p.h,v 1.1 2004/11/26 20:39:52 aquamaniac Exp $
+ cvs         : $Id: olddb_p.h 609 2004-11-26 20:39:52Z aquamaniac $
  begin       : Thu Oct 30 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
