@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: buffer.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: buffer.c,v 1.53 2005/08/04 04:55:44 aquamaniac Exp $
+    cvs         : $Id: buffer.c 987 2006-02-14 02:10:29Z aquamaniac $
     begin       : Fri Sep 12 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -48,7 +48,7 @@ GWEN_BUFFER *GWEN_Buffer_new(char *buffer,
   if (!buffer) {
     /* allocate buffer */
     if (size) {
-      bf->realPtr=(char*)malloc(size+1);
+      bf->realPtr=(char*)GWEN_Memory_malloc(size+1);
       assert(bf->realPtr);
       bf->ptr=bf->realPtr;
       bf->realBufferSize=size+1;
@@ -80,7 +80,7 @@ GWEN_BUFFER *GWEN_Buffer_new(char *buffer,
 void GWEN_Buffer_free(GWEN_BUFFER *bf){
   if (bf) {
     if (bf->flags & GWEN_BUFFER_FLAGS_OWNED)
-      free(bf->realPtr);
+      GWEN_Memory_dealloc(bf->realPtr);
     if (bf->bio) {
       if (bf->flags & GWEN_BUFFER_FLAGS_OWN_BIO) {
         GWEN_BufferedIO_free(bf->bio);
@@ -98,7 +98,7 @@ GWEN_BUFFER *GWEN_Buffer_dup(GWEN_BUFFER *bf) {
 
   GWEN_NEW_OBJECT(GWEN_BUFFER, newbf);
   if (bf->realPtr && bf->realBufferSize) {
-    newbf->realPtr=(char*)malloc(bf->realBufferSize);
+    newbf->realPtr=(char*)GWEN_Memory_malloc(bf->realBufferSize);
     newbf->ptr=newbf->realPtr+(bf->ptr-bf->realPtr);
     newbf->realBufferSize=bf->realBufferSize;
     newbf->bufferSize=bf->bufferSize;
@@ -269,7 +269,7 @@ int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 size) {
   assert(bf);
   /*DBG_VERBOUS(GWEN_LOGDOMAIN, "Allocating %d bytes", size);*/
   /*if (bf->pos+size>bf->bufferSize) {*/
-  if (bf->bytesUsed+size > bf->bufferSize) {
+  if (bf->bytesUsed+(size+1) > bf->bufferSize) {
     /* need to realloc */
     GWEN_TYPE_UINT32 nsize;
     GWEN_TYPE_UINT32 noffs;
@@ -289,7 +289,7 @@ int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 size) {
     reserved=bf->ptr-bf->realPtr;
     /* this is the raw number of bytes we need */
     /*nsize=bf->pos+size-bf->bufferSize;*/
-    nsize=bf->bytesUsed+size-bf->bufferSize;
+    nsize=bf->bytesUsed+(size+1)-bf->bufferSize;
     /* round it up */
     nsize=(nsize+(bf->step-1));
     nsize&=~(bf->step-1);
@@ -308,7 +308,8 @@ int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 size) {
     }
     DBG_VERBOUS(GWEN_LOGDOMAIN, "Reallocating from %d to %d bytes",
                 bf->bufferSize, nsize);
-    p=realloc(bf->realPtr, nsize+1); /* we always add a NULL character */
+    /* we always add a NULL character */
+    p=GWEN_Memory_realloc(bf->realPtr, nsize+1);
     if (!p) {
       DBG_ERROR(GWEN_LOGDOMAIN, "Realloc failed.");
       if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
@@ -504,18 +505,6 @@ int GWEN_Buffer_AppendBuffer(GWEN_BUFFER *bf,
 
 
 
-GWEN_TYPE_UINT32 GWEN_Buffer_RoomLeft(GWEN_BUFFER *bf){
-  assert(bf);
-
-  DBG_WARN(GWEN_LOGDOMAIN,
-           "You should better use \"GWEN_Buffer_AllocRoom\"");
-  if (bf->mode & GWEN_BUFFER_MODE_DYNAMIC)
-    return bf->hardLimit-bf->bytesUsed;
-  return (bf->bufferSize-bf->bytesUsed);
-}
-
-
-
 GWEN_TYPE_UINT32 GWEN_Buffer_GetMaxUnsegmentedWrite(GWEN_BUFFER *bf){
   assert(bf);
 
@@ -524,13 +513,6 @@ GWEN_TYPE_UINT32 GWEN_Buffer_GetMaxUnsegmentedWrite(GWEN_BUFFER *bf){
 
 
 
-GWEN_TYPE_UINT32 GWEN_Buffer_BytesLeft(GWEN_BUFFER *bf){
-  DBG_WARN(GWEN_LOGDOMAIN,
-           "You should better use \"GWEN_Buffer_GetBytesLeft\"");
-  return GWEN_Buffer_GetBytesLeft(bf);
-}
-
-
 GWEN_TYPE_UINT32 GWEN_Buffer_GetBytesLeft(GWEN_BUFFER *bf){
   assert(bf);
 
