@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: buffer.h 987 2006-02-14 02:10:29Z aquamaniac $
+    cvs         : $Id: buffer.h 1043 2006-05-04 20:54:17Z martin $
     begin       : Fri Sep 12 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -414,13 +414,6 @@ GWENHYWFAR_API
 GWEN_TYPE_UINT32 GWEN_Buffer_GetMaxUnsegmentedWrite(GWEN_BUFFER *bf);
 
 
-/**
- * Returns the number of bytes from pos to the end of the used area.
- * Deprecated, please use @ref GWEN_Buffer_GetBytesLeft instead.
- */
-GWENHYWFAR_API
-GWEN_TYPE_UINT32 GWEN_Buffer_BytesLeft(GWEN_BUFFER *bf);
-
 /**
  * Returns the number of bytes from pos to the end of the used area.
  */
