@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: error.h 930 2005-11-21 06:14:00Z aquamaniac $
+    cvs         : $Id: error.h 1048 2006-05-17 17:15:35Z martin $
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -130,6 +130,8 @@ extern "C" {
 /* new error codes in GWEN2 */
 #define GWEN_ERROR_NOT_CONNECTED        (-100)
 #define GWEN_ERROR_BAD_DATA             (-101)
+#define GWEN_ERROR_FOUND                (-102)
+#define GWEN_ERROR_IO                   (-103)
 
 /*@}*/
 
