@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: idlist_p.h 501 2004-08-09 14:26:06Z aquamaniac $
+    cvs         : $Id: idlist_p.h 1066 2006-05-20 04:47:53Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -25,8 +25,6 @@
  *                                                                         *
  ***************************************************************************/
 
-
-
 #ifndef GWENHYWFAR_IDLIST_P_H
 #define GWENHYWFAR_IDLIST_P_H
 
@@ -35,7 +33,7 @@
 #include <gwenhywfar/idlist.h>
 
 
-#define GWEN_IDTABLE_MAXENTRIES 16
+#define GWEN_IDTABLE_MAXENTRIES 32
 
 
 typedef struct GWEN_IDTABLE GWEN_IDTABLE;
@@ -61,6 +59,11 @@ GWEN_TYPE_UINT32 GWEN_IdTable_GetFirstId(GWEN_IDTABLE *idt);
 GWEN_TYPE_UINT32 GWEN_IdTable_GetNextId(GWEN_IDTABLE *idt);
 unsigned int GWEN_IdTable_GetCount(const GWEN_IDTABLE *idt);
 
+GWEN_TYPE_UINT32 GWEN_IdTable_GetFirstId2(const GWEN_IDTABLE *idt,
+                                          GWEN_TYPE_UINT32 *tabIdx);
+GWEN_TYPE_UINT32 GWEN_IdTable_GetNextId2(const GWEN_IDTABLE *idt,
+                                         GWEN_TYPE_UINT32 *tabIdx);
+
 void GWEN_IdList_Clean(GWEN_IDLIST *idl);
 
 struct GWEN_IDLIST {
