@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: logger.c 957 2005-12-23 01:43:18Z aquamaniac $
+    cvs         : $Id: logger.c 1067 2006-05-22 15:25:23Z christian $
     begin       : Sun Dec 05 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -43,11 +43,15 @@
 # include <syslog.h>
 #endif
 #include <string.h>
-#include <strings.h>
+#ifdef HAVE_STRINGS_H
+# include <strings.h>
+#endif
 #ifdef HAVE_TIME_H
 # include <time.h>
 #endif
-#include <unistd.h>
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
 
 
 static GWEN_LOGGER_DOMAIN *gwen_loggerdomains=0;
