@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: logger.h 892 2005-11-03 00:20:45Z aquamaniac $
+    cvs         : $Id: logger.h 1039 2006-04-18 16:11:39Z christian $
     begin       : Sun Dec 05 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -102,11 +102,7 @@ void GWEN_Logger_AddLogger(GWEN_LOGGER *oldLogger, GWEN_LOGGER *newLogger);
  * GWEN_Logger_Open on that logger prior to calling this function.
  */
 GWENHYWFAR_API
-void GWEN_Logger_SetDefaultLogger(GWEN_LOGGER *lg) 
-#ifdef __GNUC__
-       __attribute__((deprecated))
-#endif /* __GNUC__ */
-       ;
+void GWEN_Logger_SetDefaultLogger(GWEN_LOGGER *lg) DEPRECATED ;
 
 
 /**
