@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: stringlist.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: stringlist.h,v 1.14 2005/07/09 13:38:17 aquamaniac Exp $
+ cvs         : $Id: stringlist.h 1030 2006-04-07 09:53:56Z martin $
  begin       : Thu Apr 03 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -81,12 +81,17 @@ GWENHYWFAR_API
 GWENHYWFAR_API
   const char *GWEN_StringListEntry_Data(const GWEN_STRINGLISTENTRY *se);
 
+GWENHYWFAR_API
+  void GWEN_StringListEntry_SetData(GWEN_STRINGLISTENTRY *se,
+                                    const char *s);
+
 /**
  * Normally this group of functions ignores cases when comparing two strings.
  * You can change this behaviour here.
  * @param sl string list
  * @param i if 0 then cases are ignored
  */
+GWENHYWFAR_API
 void GWEN_StringList_SetSenseCase(GWEN_STRINGLIST *sl, int i);
 
 /**
@@ -96,6 +101,7 @@ void GWEN_StringList_SetSenseCase(GWEN_STRINGLIST *sl, int i);
  * @param sl string list
  * @param i if 0 then reference counters are honoured
  */
+GWENHYWFAR_API
 void GWEN_StringList_SetIgnoreRefCount(GWEN_STRINGLIST *sl, int i);
 
 /**
@@ -158,6 +164,9 @@ void *GWEN_StringList_ForEach(const GWEN_STRINGLIST *l,
 GWENHYWFAR_API
 const char *GWEN_StringList_FirstString(const GWEN_STRINGLIST *l);
 
+GWENHYWFAR_API
+const char *GWEN_StringList_StringAt(const GWEN_STRINGLIST *l, int idx);
+
 
 /** Sorts this list. Internally this uses qsort(3), so the sorting
  * should be reasonably fast even for large lists.
