@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: crypt.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: crypt.h,v 1.24 2005/09/29 03:21:55 aquamaniac Exp $
+ cvs         : $Id: crypt.h 985 2006-02-10 03:17:04Z aquamaniac $
  begin       : Thu Nov 06 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -41,6 +41,7 @@
 extern "C" {
 #endif
 
+
 #define GWEN_CRYPT_ERROR_TYPE "Crypt"
 #define GWEN_CRYPT_ERROR_ALREADY_REGISTERED 1
 #define GWEN_CRYPT_ERROR_NOT_REGISTERED     2
@@ -61,35 +62,17 @@ extern "C" {
  */
 #define GWEN_CRYPT_FLAG_DISABLE_SMALLER_SIGNATURE 0x00000001
 
+GWENHYWFAR_API
 int GWEN_Crypt_IsAvailable();
 
 
-/** @name Functions expected in implementation
- *
- */
-/*@{*/
-/**
- * This function is expected to register all it's crypto service
- * providers. It is called when the GWEN_Crypt module is initialized.
- */
-GWENHYWFAR_API
-  GWEN_ERRORCODE GWEN_CryptImpl_Init();
-
-/**
- * This function is called when the GWEN_Crypt module is deinitialized.
- * It can be used to release allocated data. It MUST NOT unregister any
- * crypt key type, this is done automatically.
- */
-GWENHYWFAR_API
-  GWEN_ERRORCODE GWEN_CryptImpl_Fini();
-/*@}*/
-
-
 typedef struct GWEN_CRYPTKEY GWEN_CRYPTKEY;
 
 GWEN_INHERIT_FUNCTION_LIB_DEFS(GWEN_CRYPTKEY, GWENHYWFAR_API)
 GWEN_LIST_FUNCTION_LIB_DEFS(GWEN_CRYPTKEY, GWEN_CryptKey, GWENHYWFAR_API)
 GWEN_LIST2_FUNCTION_LIB_DEFS(GWEN_CRYPTKEY, GWEN_CryptKey, GWENHYWFAR_API)
+
+GWENHYWFAR_API
 void GWEN_CryptKey_List2_freeAll(GWEN_CRYPTKEY_LIST2 *stl);
 
 
@@ -155,6 +138,7 @@ GWENHYWFAR_API
 
 GWENHYWFAR_API
   int GWEN_CryptKey_IsPublic(const GWEN_CRYPTKEY *key);
+
 GWENHYWFAR_API
   void GWEN_CryptKey_SetPublic(GWEN_CRYPTKEY *key, int i);
 
@@ -182,25 +166,28 @@ GWENHYWFAR_API
 unsigned int GWEN_CryptKey_GetChunkSize(const GWEN_CRYPTKEY *key);
 
 GWENHYWFAR_API
-  GWEN_CRYPTKEY *GWEN_CryptKey_FromDb(GWEN_DB_NODE *db);
+  GWEN_CRYPTKEY *GWEN_CryptKey_fromDb(GWEN_DB_NODE *db);
 
 GWENHYWFAR_API
-  GWEN_ERRORCODE GWEN_CryptKey_ToDb(const GWEN_CRYPTKEY *key,
+  GWEN_ERRORCODE GWEN_CryptKey_toDb(const GWEN_CRYPTKEY *key,
 				    GWEN_DB_NODE *db,
 				    int pub);
 
 GWENHYWFAR_API
 GWEN_TYPE_UINT32 GWEN_CryptKey_GetFlags(const GWEN_CRYPTKEY *key);
+
 GWENHYWFAR_API
 void GWEN_CryptKey_SetFlags(GWEN_CRYPTKEY *key, GWEN_TYPE_UINT32 fl);
+
 GWENHYWFAR_API
 void GWEN_CryptKey_AddFlags(GWEN_CRYPTKEY *key, GWEN_TYPE_UINT32 fl);
+
 GWENHYWFAR_API
 void GWEN_CryptKey_SubFlags(GWEN_CRYPTKEY *key, GWEN_TYPE_UINT32 fl);
 
 
 /**
- * This is a conveniance function.
+ * This is a convenience function.
  * Sets the key data. This can be used by the application for keys which
  * use the variable "keydata" when calling @ref GWEN_CryptKey_FromDb (such
  * as most symmetric keys).
@@ -214,6 +201,7 @@ GWENHYWFAR_API
  * Creates a password from a given string. Depending on the size needed
  * a hash-algorithm is applied to the given password.
  */
+GWENHYWFAR_API
 int GWEN_CryptKey_FromPassword(const char *password,
 			       unsigned char *buffer,
 			       unsigned int bsize);
@@ -229,6 +217,7 @@ int GWEN_CryptKey_FromPassword(const char *password,
  * function uses very well documented algorithms to create key data.
  * </p>
  */
+GWENHYWFAR_API
 int GWEN_CryptKey_FromPasswordSSL(const char *password,
                                   unsigned char *buffer,
                                   unsigned int bsize);
@@ -239,6 +228,7 @@ int GWEN_CryptKey_FromPasswordSSL(const char *password,
  * use the variable "keydata" when calling @ref GWEN_CryptKey_ToDb (such
  * as most symmetric keys).
  */
+GWENHYWFAR_API
 GWEN_ERRORCODE GWEN_CryptKey_GetData(GWEN_CRYPTKEY *key,
 				     char *buffer,
 				     unsigned int *bsize);
@@ -272,38 +262,48 @@ void GWEN_CryptKey_SetKeySpec(GWEN_CRYPTKEY *key,
  */
 GWENHYWFAR_API
 int GWEN_CryptKey_GetStatus(const GWEN_CRYPTKEY *key);
+
 GWENHYWFAR_API
 void GWEN_CryptKey_SetStatus(GWEN_CRYPTKEY *key, int i);
 
 
 GWENHYWFAR_API
   const char *GWEN_CryptKey_GetKeyType(const GWEN_CRYPTKEY *key);
+
 GWENHYWFAR_API
   void GWEN_CryptKey_SetKeyType(GWEN_CRYPTKEY *key,
 				const char *s);
 
 GWENHYWFAR_API
   const char *GWEN_CryptKey_GetKeyName(const GWEN_CRYPTKEY *key);
+
 GWENHYWFAR_API
   void GWEN_CryptKey_SetKeyName(GWEN_CRYPTKEY *key,
 				const char *s);
 
 GWENHYWFAR_API
   const char *GWEN_CryptKey_GetOwner(const GWEN_CRYPTKEY *key);
+
 GWENHYWFAR_API
   void GWEN_CryptKey_SetOwner(GWEN_CRYPTKEY *key,
 			      const char *s);
 GWENHYWFAR_API
   unsigned int GWEN_CryptKey_GetNumber(const GWEN_CRYPTKEY *key);
+
 GWENHYWFAR_API
   void GWEN_CryptKey_SetNumber(GWEN_CRYPTKEY *key,
 			       unsigned int i);
 GWENHYWFAR_API
   unsigned int GWEN_CryptKey_GetVersion(const GWEN_CRYPTKEY *key);
+
 GWENHYWFAR_API
   void GWEN_CryptKey_SetVersion(GWEN_CRYPTKEY *key,
 				unsigned int i);
 
+GWENHYWFAR_API
+unsigned int GWEN_CryptKey_GetKeyLength(const GWEN_CRYPTKEY *key);
+
+
 #if (defined(GWEN_EXTEND_CRYPTKEY) || defined(DOXYGEN))
 /**
  * This function is only available if you define <i>GWEN_EXTEND_CRYPTKEY</i>
@@ -325,6 +325,10 @@ GWENHYWFAR_API
 GWENHYWFAR_API
   void GWEN_CryptKey_SetKeyData(GWEN_CRYPTKEY *key,
 				void *kd);
+
+GWENHYWFAR_API
+void GWEN_CryptKey_SetKeyLength(GWEN_CRYPTKEY *key, unsigned int i);
+
 #endif
 
 GWENHYWFAR_API
@@ -333,6 +337,7 @@ GWENHYWFAR_API
 #if (defined(GWEN_EXTEND_CRYPTKEY) || defined(DOXYGEN))
 GWENHYWFAR_API
   void GWEN_CryptKey_IncrementOpenCount(GWEN_CRYPTKEY *key);
+
 GWENHYWFAR_API
   void GWEN_CryptKey_DecrementOpenCount(GWEN_CRYPTKEY *key);
 #endif
@@ -414,6 +419,7 @@ GWENHYWFAR_API
    */
 GWENHYWFAR_API
   GWEN_ERRORCODE GWEN_Crypt_RegisterProvider(GWEN_CRYPTKEY_PROVIDER *pr);
+
 GWENHYWFAR_API
   GWEN_ERRORCODE GWEN_Crypt_UnregisterProvider(GWEN_CRYPTKEY_PROVIDER *pr);
 
@@ -421,6 +427,10 @@ GWENHYWFAR_API
   void GWEN_Crypt_UnregisterAllProviders();
 
 
+GWENHYWFAR_API
+long int GWEN_Random();
+
+
 #ifdef __cplusplus
 }
 #endif
