@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: crypt_p.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: crypt_p.h,v 1.12 2005/09/29 03:21:55 aquamaniac Exp $
+ cvs         : $Id: crypt_p.h 870 2005-09-29 03:21:55Z aquamaniac $
  begin       : Thu Nov 06 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
