@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: keyspec.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: keyspec.c,v 1.17.2.1 2005/11/16 09:56:40 cstim Exp $
+    cvs         : $Id: keyspec.c 1001 2006-03-15 15:47:27Z aquamaniac $
     begin       : Sat Nov 08 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -39,6 +39,7 @@
 
 
 GWEN_INHERIT_FUNCTIONS(GWEN_KEYSPEC)
+GWEN_LIST_FUNCTIONS(GWEN_KEYSPEC, GWEN_KeySpec)
 GWEN_LIST2_FUNCTIONS(GWEN_KEYSPEC, GWEN_KeySpec)
 
 
@@ -48,6 +49,7 @@ GWEN_KEYSPEC *GWEN_KeySpec_new(){
   GWEN_NEW_OBJECT(GWEN_KEYSPEC, ks);
   DBG_MEM_INC("GWEN_KEYSPEC", 0);
   GWEN_INHERIT_INIT(GWEN_KEYSPEC, ks);
+  GWEN_LIST_INIT(GWEN_KEYSPEC, ks);
   ks->number=1;
   ks->version=1;
   return ks;
@@ -58,11 +60,12 @@ GWEN_KEYSPEC *GWEN_KeySpec_new(){
 void GWEN_KeySpec_free(GWEN_KEYSPEC *ks){
   if (ks) {
     DBG_MEM_DEC("GWEN_KEYSPEC");
+    GWEN_LIST_FINI(GWEN_KEYSPEC, ks);
     GWEN_INHERIT_FINI(GWEN_KEYSPEC, ks);
     free(ks->keyType);
     free(ks->keyName);
     free(ks->owner);
-    free(ks);
+    GWEN_FREE_OBJECT(ks);
   }
 }
 
@@ -82,42 +85,12 @@ GWEN_KEYSPEC *GWEN_KeySpec_dup(const GWEN_KEYSPEC *ks){
   newKs->number=ks->number;
   newKs->version=ks->version;
   newKs->status=ks->status;
+  newKs->keyLength=ks->keyLength;
   return newKs;
 }
 
 
 
-GWEN_KEYSPEC *GWEN_KeySpec_Next(GWEN_KEYSPEC *ks){
-  assert(ks);
-  return ks->next;
-}
-
-
-const GWEN_KEYSPEC *GWEN_KeySpec_ConstNext(const GWEN_KEYSPEC *ks){
-  assert(ks);
-  return ks->next;
-}
-
-
-
-void GWEN_KeySpec_Add(GWEN_KEYSPEC *ks,
-                             GWEN_KEYSPEC **head){
-  assert(ks);
-  assert(head);
-  GWEN_LIST_ADD(GWEN_KEYSPEC, ks, head);
-}
-
-
-
-void GWEN_KeySpec_Del(GWEN_KEYSPEC *ks,
-                             GWEN_KEYSPEC **head){
-  assert(ks);
-  assert(head);
-  GWEN_LIST_DEL(GWEN_KEYSPEC, ks, head);
-}
-
-
-
 const char *GWEN_KeySpec_GetKeyType(const GWEN_KEYSPEC *ks){
   assert(ks);
   return ks->keyType;
@@ -212,24 +185,21 @@ void GWEN_KeySpec_SetStatus(GWEN_KEYSPEC *ks, int i){
 
 
 
-void GWEN_KeySpec_Clear(GWEN_KEYSPEC **head){
-  GWEN_KEYSPEC *ks;
-
-  ks=*head;
-  DBG_INFO(GWEN_LOGDOMAIN, "Clearing list of KeySpecs");
-  while(ks) {
-    GWEN_KEYSPEC *nks;
-
-    nks=ks->next;
-    GWEN_KeySpec_free(ks);
-    ks=nks;
-  } /* while */
-  DBG_INFO(GWEN_LOGDOMAIN, "Clearing list of KeySpecs: done");
-  *head=0;
+unsigned int GWEN_KeySpec_GetKeyLength(const GWEN_KEYSPEC *ks) {
+  assert(ks);
+  return ks->keyLength;
 }
 
 
 
+void GWEN_KeySpec_SetKeyLength(GWEN_KEYSPEC *ks, unsigned int i) {
+  assert(ks);
+  ks->keyLength=i;
+}
+
+
+
+
 void GWEN_KeySpec_Dump(const GWEN_KEYSPEC *ks, FILE *f, unsigned int indent){
   unsigned int i;
 
@@ -239,17 +209,19 @@ void GWEN_KeySpec_Dump(const GWEN_KEYSPEC *ks, FILE *f, unsigned int indent){
   for (i=0; i<indent; i++) fprintf(f, " ");
   fprintf(f, "--------------------------------------------------\n");
   for (i=0; i<indent; i++) fprintf(f, " ");
-  fprintf(f, "Status : %02x\n", ks->status);
+  fprintf(f, "Status    : %02x\n", ks->status);
   for (i=0; i<indent; i++) fprintf(f, " ");
-  fprintf(f, "KeyType : %s\n", ks->keyType);
+  fprintf(f, "KeyType   : %s\n", ks->keyType);
   for (i=0; i<indent; i++) fprintf(f, " ");
-  fprintf(f, "KeyName : %s\n", ks->keyName);
+  fprintf(f, "KeyName   : %s\n", ks->keyName);
   for (i=0; i<indent; i++) fprintf(f, " ");
-  fprintf(f, "Owner   : %s\n", ks->owner);
+  fprintf(f, "Owner     : %s\n", ks->owner);
   for (i=0; i<indent; i++) fprintf(f, " ");
-  fprintf(f, "Number  : %d\n", ks->number);
+  fprintf(f, "Number    : %d\n", ks->number);
   for (i=0; i<indent; i++) fprintf(f, " ");
-  fprintf(f, "Version : %d\n", ks->version);
+  fprintf(f, "Version   : %d\n", ks->version);
+  for (i=0; i<indent; i++) fprintf(f, " ");
+  fprintf(f, "KeyLength : %d\n", ks->keyLength);
 }
 
 
@@ -273,7 +245,9 @@ int GWEN_KeySpec_ToDb(const GWEN_KEYSPEC *ks, GWEN_DB_NODE *n) {
   GWEN_DB_SetIntValue(n,
                       GWEN_DB_FLAGS_DEFAULT | GWEN_DB_FLAGS_OVERWRITE_VARS,
                       "status", ks->status);
-
+  GWEN_DB_SetIntValue(n,
+                      GWEN_DB_FLAGS_DEFAULT | GWEN_DB_FLAGS_OVERWRITE_VARS,
+                      "keyLength", ks->keyLength);
   return 0;
 }
 
@@ -294,6 +268,8 @@ int GWEN_KeySpec_FromDb(GWEN_KEYSPEC *ks, GWEN_DB_NODE *db){
                           GWEN_DB_GetIntValue(db, "version", 0, 0));
   GWEN_KeySpec_SetStatus(ks,
                          GWEN_DB_GetIntValue(db, "status", 0, 0));
+  GWEN_KeySpec_SetKeyLength(ks,
+                            GWEN_DB_GetIntValue(db, "keyLength", 0, 0));
   return 0;
 }
 
