@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: gwenhywfar.c 957 2005-12-23 01:43:18Z aquamaniac $
+ cvs         : $Id: gwenhywfar.c 1048 2006-05-17 17:15:35Z martin $
  begin       : Thu Sep 11 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -61,6 +61,8 @@
 #include "net2/net2_l.h"
 #include "base/waitcallback_l.h"
 
+#include "storage/st_storage_l.h"
+
 
 /* for regkey stuff */
 #ifdef OS_WIN32
@@ -205,6 +207,10 @@ GWEN_ERRORCODE GWEN_Init() {
       return err;
     DBG_DEBUG(GWEN_LOGDOMAIN, "Initializing DataBase IO module");
     err=GWEN_DBIO_ModuleInit();
+    if (!GWEN_Error_IsOk(err))
+      return err;
+    DBG_DEBUG(GWEN_LOGDOMAIN, "Initializing Storage module");
+    err=GWEN_StoStorage_ModuleInit();
     if (!GWEN_Error_IsOk(err))
       return err;
     DBG_DEBUG(GWEN_LOGDOMAIN, "Initializing WaitCallback module");
@@ -241,6 +247,14 @@ GWEN_ERRORCODE GWEN_Fini() {
       DBG_ERROR(GWEN_LOGDOMAIN, "GWEN_Fini: "
                 "Could not deinitialze module WaitCallback");
     }
+    if (!GWEN_Error_IsOk(GWEN_StoStorage_ModuleFini())) {
+      err=GWEN_Error_new(0,
+                         GWEN_ERROR_SEVERITY_ERR,
+                         0,
+                         GWEN_ERROR_COULD_NOT_UNREGISTER);
+      DBG_ERROR(GWEN_LOGDOMAIN, "GWEN_Fini: "
+                "Could not deinitialze module Storage");
+    }
     if (!GWEN_Error_IsOk(GWEN_DBIO_ModuleFini())) {
       err=GWEN_Error_new(0,
                          GWEN_ERROR_SEVERITY_ERR,
