@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: gwenhywfarapi.h 966 2006-01-19 14:54:39Z cstim $
+    cvs         : $Id: gwenhywfarapi.h 1048 2006-05-17 17:15:35Z martin $
     begin       : Wed Sep 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -64,6 +64,15 @@
 #endif
 
 
+#ifdef GCC_WITH_VISIBILITY_ATTRIBUTE
+# define GWENHYWFAR_EXPORT __attribute__((visibility("default")))
+# define GWENHYWFAR_NOEXPORT __attribute__((visibility("hidden")))
+#else
+# define GWENHYWFAR_EXPORT
+# define GWENHYWFAR_NOEXPORT
+#endif
+
+
 
 /* Convenience macros to test the versions of glibc and gcc. Taken
    from <features.h> which does not contain this on MinGW systems.  */
@@ -89,7 +98,8 @@
 #include <gwenhywfar/system.h>
 
 
-#ifdef __GNUC__
+#if __GNUC_PREREQ(3, 0)
+/* Only available in gcc >= 3.0.x */
 # define DEPRECATED __attribute__((deprecated))
 #else
 # define DEPRECATED
