@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: ipc_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: ipc_p.h,v 1.15 2005/10/13 05:22:49 aquamaniac Exp $
+    cvs         : $Id: ipc_p.h 892 2005-11-03 00:20:45Z aquamaniac $
     begin       : Fri May 07 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -16,8 +16,7 @@
 
 #include <gwenhywfar/ipc.h>
 #include <gwenhywfar/misc.h>
-#include <gwenhywfar/nettransportssl.h>
-#include <gwenhywfar/netconnectionhttp.h>
+#include <gwenhywfar/nl_packets.h>
 
 
 
@@ -28,24 +27,23 @@
  */
 
 typedef struct GWEN_IPCNODE GWEN_IPCNODE;
-GWEN_LIST_FUNCTION_DEFS(GWEN_IPCNODE, GWEN_IPCNode)
+GWEN_LIST_FUNCTION_DEFS(GWEN_IPCNODE, GWEN_IpcNode)
 struct GWEN_IPCNODE {
   GWEN_LIST_ELEMENT(GWEN_IPCNODE)
-  GWEN_NETCONNECTION *connection;
+  GWEN_NETLAYER *netLayer;
   int isServer;
   int isPassiveClient;
   GWEN_TYPE_UINT32 id;
   GWEN_TYPE_UINT32 mark;
   GWEN_TYPE_UINT32 usage;
   GWEN_TYPE_UINT32 flags;
-  char *baseAuth;
 
   GWEN_TYPE_UINT32 nextMsgId;
   GWEN_TYPE_UINT32 lastMsgId;
 };
-GWEN_IPCNODE *GWEN_IPCNode_new();
-void GWEN_IPCNode_free(GWEN_IPCNODE *n);
-void GWEN_IPCNode_Attach(GWEN_IPCNODE *n);
+GWEN_IPCNODE *GWEN_IpcNode_new();
+void GWEN_IpcNode_free(GWEN_IPCNODE *n);
+void GWEN_IpcNode_Attach(GWEN_IPCNODE *n);
 
 
 
@@ -56,7 +54,7 @@ void GWEN_IPCNode_Attach(GWEN_IPCNODE *n);
  */
 
 typedef struct GWEN_IPCMSG GWEN_IPCMSG;
-GWEN_LIST_FUNCTION_DEFS(GWEN_IPCMSG, GWEN_IPCMsg)
+GWEN_LIST_FUNCTION_DEFS(GWEN_IPCMSG, GWEN_IpcMsg)
 struct GWEN_IPCMSG {
   GWEN_LIST_ELEMENT(GWEN_IPCMSG)
   GWEN_IPCNODE *node;
@@ -66,9 +64,10 @@ struct GWEN_IPCMSG {
   GWEN_DB_NODE *db;
   time_t sendTime;
   time_t receivedTime;
+  GWEN_NL_PACKET *packet;
 };
-GWEN_IPCMSG *GWEN_IPCMsg_new(GWEN_IPCNODE *n);
-void GWEN_IPCMsg_free(GWEN_IPCMSG *m);
+GWEN_IPCMSG *GWEN_IpcMsg_new(GWEN_IPCNODE *n);
+void GWEN_IpcMsg_free(GWEN_IPCMSG *m);
 
 
 
@@ -79,7 +78,7 @@ void GWEN_IPCMsg_free(GWEN_IPCMSG *m);
  */
 
 typedef struct GWEN_IPC__REQUEST GWEN_IPC__REQUEST;
-GWEN_LIST_FUNCTION_DEFS(GWEN_IPC__REQUEST, GWEN_IPC__Request)
+GWEN_LIST_FUNCTION_DEFS(GWEN_IPC__REQUEST, GWEN_Ipc__Request)
 struct GWEN_IPC__REQUEST {
   GWEN_LIST_ELEMENT(GWEN_IPC__REQUEST)
   GWEN_INHERIT_ELEMENT(GWEN_IPC__REQUEST)
@@ -90,15 +89,15 @@ struct GWEN_IPC__REQUEST {
 
   int usage;
 };
-GWEN_IPC__REQUEST *GWEN_IPC__Request_new();
-void GWEN_IPC__Request_Attach(GWEN_IPC__REQUEST *r);
-void GWEN_IPC__Request_free(GWEN_IPC__REQUEST *r);
-void GWEN_IPC__Request_AddRequestMsg(GWEN_IPC__REQUEST *r, GWEN_IPCMSG *m);
-void GWEN_IPC__Request_AddResponseMsg(GWEN_IPC__REQUEST *r, GWEN_IPCMSG *m);
-int GWEN_IPC__Request_HasRequestMsg(GWEN_IPC__REQUEST *r,
+GWEN_IPC__REQUEST *GWEN_Ipc__Request_new();
+void GWEN_Ipc__Request_Attach(GWEN_IPC__REQUEST *r);
+void GWEN_Ipc__Request_free(GWEN_IPC__REQUEST *r);
+void GWEN_Ipc__Request_AddRequestMsg(GWEN_IPC__REQUEST *r, GWEN_IPCMSG *m);
+void GWEN_Ipc__Request_AddResponseMsg(GWEN_IPC__REQUEST *r, GWEN_IPCMSG *m);
+int GWEN_Ipc__Request_HasRequestMsg(GWEN_IPC__REQUEST *r,
                                   GWEN_TYPE_UINT32 nid,
                                   GWEN_TYPE_UINT32 id);
-GWEN_IPCMSG_LIST *GWEN_IPC__Request_GetRequestMsgList(const GWEN_IPC__REQUEST *r);
+GWEN_IPCMSG_LIST *GWEN_Ipc__Request_GetRequestMsgList(const GWEN_IPC__REQUEST *r);
 
 
 
@@ -112,7 +111,6 @@ GWEN_IPCMSG_LIST *GWEN_IPC__Request_GetRequestMsgList(const GWEN_IPC__REQUEST *r
 
 struct GWEN_IPCMANAGER {
   char *application;
-  GWEN_TYPE_UINT32 libId;
   GWEN_IPCNODE_LIST *nodes;
   GWEN_IPC__REQUEST_LIST *outRequests;
   GWEN_IPC__REQUEST_LIST *newInRequests;
@@ -121,35 +119,30 @@ struct GWEN_IPCMANAGER {
   GWEN_TYPE_UINT32 usage;
 };
 
-GWEN_IPC__REQUEST *GWEN_IPCManager__FindRequest(GWEN_IPCMANAGER *mgr,
+GWEN_IPC__REQUEST *GWEN_IpcManager__FindRequest(GWEN_IPCMANAGER *mgr,
                                               GWEN_TYPE_UINT32 rid,
                                               GWEN_IPC__REQUEST *r);
-int GWEN_IPCManager__SendMsg(GWEN_IPCMANAGER *mgr,
+int GWEN_IpcManager__SendMsg(GWEN_IPCMANAGER *mgr,
                              GWEN_IPCMSG *m);
-GWEN_TYPE_UINT32 GWEN_IPCManager__AddService(GWEN_IPCMANAGER *mgr,
-                                             GWEN_NETTRANSPORT *tr,
-                                             GWEN_TYPE_UINT32 mark,
-                                             int isServer);
-GWEN_IPCMSG *GWEN_IPCManager__MakeErrorResponse(GWEN_IPCMANAGER *mgr,
+GWEN_IPCMSG *GWEN_IpcManager__MakeErrorResponse(GWEN_IPCMANAGER *mgr,
                                                 GWEN_IPCMSG *m,
                                                 int code,
                                                 const char *txt);
-int GWEN_IPCManager__Collect(GWEN_IPCMANAGER *mgr, int maxMsg);
-int GWEN_IPCManager__CheckRequests(GWEN_IPCMANAGER *mgr);
+int GWEN_IpcManager__CheckRequests(GWEN_IPCMANAGER *mgr);
 
-void GWEN_IPCManager__Connection_Up(GWEN_NETCONNECTION *conn);
-void GWEN_IPCManager__Connection_Down(GWEN_NETCONNECTION *conn);
-
-
-void GWEN_IPCManager__RemoveNodeRequestMessages(GWEN_IPCMANAGER *mgr,
+void GWEN_IpcManager__RemoveNodeRequestMessages(GWEN_IPCMANAGER *mgr,
                                                 GWEN_IPCNODE *n,
                                                 GWEN_IPC__REQUEST_LIST *rl,
                                                 const char *msgType);
+int GWEN_IpcManager__HandlePacket(GWEN_IPCMANAGER *mgr,
+                                  GWEN_IPCNODE *n,
+                                  GWEN_NL_PACKET *pk);
 
-void GWEN_IPCNode_Dump(GWEN_IPCNODE *n, FILE *f, int indent);
-void GWEN_IPCMsg_Dump(GWEN_IPCMSG *m, FILE *f, int indent);
-void GWEN_IPC__Request_Dump(GWEN_IPC__REQUEST *r, FILE *f, int indent);
+int GWEN_IpcManager__Work(GWEN_IPCMANAGER *mgr);
 
+void GWEN_IpcNode_Dump(GWEN_IPCNODE *n, FILE *f, int indent);
+void GWEN_IpcMsg_Dump(GWEN_IPCMSG *m, FILE *f, int indent);
+void GWEN_Ipc__Request_Dump(GWEN_IPC__REQUEST *r, FILE *f, int indent);
 
 
 #endif /* GWEN_IPC_P_H */
