@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: requestmgr.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: requestmgr.h,v 1.1 2005/10/13 05:22:49 aquamaniac Exp $
+    cvs         : $Id: requestmgr.h 961 2006-01-11 23:19:00Z aquamaniac $
     begin       : Fri May 07 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -20,20 +20,26 @@ typedef struct GWEN_IPC_REQUEST_MANAGER GWEN_IPC_REQUEST_MANAGER;
 #include <gwenhywfar/request.h>
 #include <gwenhywfar/ipc.h>
 
-
+GWENHYWFAR_API 
 GWEN_IPC_REQUEST_MANAGER *GWEN_IpcRequestManager_new(GWEN_IPCMANAGER *ipcMgr);
+
+GWENHYWFAR_API 
 void GWEN_IpcRequestManager_free(GWEN_IPC_REQUEST_MANAGER *rm);
 
 
+GWENHYWFAR_API 
 GWEN_IPCMANAGER*
   GWEN_IpcRequestManager_GetIpcManager(const GWEN_IPC_REQUEST_MANAGER *rm);
+GWENHYWFAR_API 
 GWEN_IPC_REQUEST_LIST*
   GWEN_IpcRequestManager_GetRequests(const GWEN_IPC_REQUEST_MANAGER *rm);
 
 
+GWENHYWFAR_API 
 void GWEN_IpcRequestManager_AddRequest(GWEN_IPC_REQUEST_MANAGER *rm,
                                        GWEN_IPC_REQUEST *rq);
 
+GWENHYWFAR_API 
 int GWEN_IpcRequestManager_Work(GWEN_IPC_REQUEST_MANAGER *rm);
 
 
