@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: requestmgr_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: requestmgr_p.h,v 1.1 2005/10/13 05:22:49 aquamaniac Exp $
+    cvs         : $Id: requestmgr_p.h 874 2005-10-13 05:22:49Z aquamaniac $
     begin       : Fri May 07 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
