@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: nl_packets.c 979 2006-02-04 01:47:12Z aquamaniac $
+    cvs         : $Id: nl_packets.c 1073 2006-06-15 20:27:32Z martin $
     begin       : Mon Feb 09 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -407,7 +407,7 @@ GWEN_NETLAYER_RESULT GWEN_NetLayerPackets__ReadWork(GWEN_NETLAYER *nl) {
       return GWEN_NetLayerResult_Error;
     }
     if (bsize==0) {
-      DBG_NOTICE(GWEN_LOGDOMAIN, "Message finished");
+      DBG_INFO(GWEN_LOGDOMAIN, "Message finished");
       pk->status=GWEN_NL_PacketStatus_Finished;
       GWEN_NL_Packet_List_Add(pk, nld->inPackets);
       nld->currentInPacket=GWEN_NL_Packet_new();
