@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: inetaddr_l.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: inetaddr_l.h,v 1.1 2004/05/06 11:02:04 aquamaniac Exp $
+    cvs         : $Id: inetaddr_l.h 349 2004-05-06 11:02:04Z aquamaniac $
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
