@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: inetsocket.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: inetsocket.h,v 1.13 2004/08/02 02:49:03 aquamaniac Exp $
+    cvs         : $Id: inetsocket.h 978 2006-02-03 17:41:49Z aquamaniac $
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -72,7 +72,8 @@ typedef enum {
   GWEN_SocketTypeTCP=1,
   GWEN_SocketTypeUDP,
   GWEN_SocketTypeRAW,
-  GWEN_SocketTypeUnix
+  GWEN_SocketTypeUnix,
+  GWEN_SocketTypeFile
 } GWEN_SOCKETTYPE;
 
 
@@ -142,6 +143,8 @@ GWENHYWFAR_API int GWEN_SocketSet_GetSocketCount(GWEN_SOCKETSET *ssp);
  */
 GWENHYWFAR_API GWEN_SOCKET *GWEN_Socket_new(GWEN_SOCKETTYPE socketType);
 
+GWENHYWFAR_API GWEN_SOCKET *GWEN_Socket_fromFile(int fd);
+
 /**
  * Destructor.
  */
