@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: inetaddr.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: inetaddr.c,v 1.14 2004/11/19 17:13:40 aquamaniac Exp $
+    cvs         : $Id: inetaddr.c 957 2005-12-23 01:43:18Z aquamaniac $
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -223,7 +223,7 @@ void GWEN_InetAddr_free(GWEN_INETADDRESS *ia){
     DBG_INFO(GWEN_LOGDOMAIN, "Free InetAddr, makes %d",GWEN_INETADDR__Counter);
 #endif
     free(ia->address);
-    free(ia);
+    GWEN_FREE_OBJECT(ia);
   }
 }
 
