@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: inetsocket.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: inetsocket.c,v 1.11 2004/08/20 09:17:28 aquamaniac Exp $
+    cvs         : $Id: inetsocket.c 1030 2006-04-07 09:53:56Z martin $
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -110,7 +110,7 @@ GWEN_SOCKETSET *GWEN_SocketSet_new() {
 void GWEN_SocketSet_free(GWEN_SOCKETSET *ssp) {
   if (ssp) {
     FD_ZERO(&(ssp->set));
-    free(ssp);
+    GWEN_FREE_OBJECT(ssp);
   }
 }
 
@@ -174,9 +174,21 @@ GWEN_SOCKET *GWEN_Socket_new(GWEN_SOCKETTYPE socketType){
 
 
 
+GWEN_SOCKET *GWEN_Socket_fromFile(int fd) {
+  GWEN_SOCKET *sp;
+
+  GWEN_NEW_OBJECT(GWEN_SOCKET, sp);
+  sp->type=GWEN_SocketTypeFile;
+  sp->socket=fd;
+  return sp;
+}
+
+
+
 void GWEN_Socket_free(GWEN_SOCKET *sp){
-  if (sp)
-    free(sp);
+  if (sp) {
+    GWEN_FREE_OBJECT(sp);
+  }
 }
 
 
@@ -422,29 +434,31 @@ GWEN_ERRORCODE GWEN_Socket_Select(GWEN_SOCKETSET *rs,
   s1=s2=s3=0;
   h1=h2=h3=0;
 
-  if (rs) {
+  if (rs && rs->count) {
     h1=rs->highest;
     s1=&rs->set;
   }
-  if (ws) {
+  if (ws && ws->count) {
     h2=ws->highest;
     s2=&ws->set;
   }
-  if (xs) {
+  if (xs && xs->count) {
     h3=xs->highest;
     s3=&xs->set;
   }
   h=(h1>h2)?h1:h2;
   h=(h>h3)?h:h3;
-  if (timeout<0)
+  if (timeout<0) {
     /* wait for ever */
     rv=select(h+1,s1,s2,s3,0);
+  }
   else {
     /* return immediately */
     tv.tv_sec=0;
     tv.tv_usec=timeout*1000;
     rv=select(h+1,s1,s2,s3,&tv);
   }
+
   if (rv<0) {
     /* error */
     if (errno==EINTR)
@@ -509,6 +523,16 @@ GWEN_ERRORCODE GWEN_Socket_Write(GWEN_SOCKET *sp,
   assert(sp);
   assert(buffer);
   assert(bsize);
+
+#ifdef OS_DARWIN
+  /* this is just a temporary ugly hack for OS X, this has to be investigated
+   * further */
+  if (sp->haveWaited==0) {
+    sleep(1);
+    sp->haveWaited=1;
+  }
+#endif
+
 #ifndef MSG_NOSIGNAL
   i=send(sp->socket,buffer, *bsize,0);
 #else
