@@ -1,7 +1,7 @@
 /***************************************************************************
-  $RCSfile: process.h,v $
+  $RCSfile$
                              -------------------
-    cvs         : $Id: process.h,v 1.5 2004/08/20 20:35:27 aquamaniac Exp $
+    cvs         : $Id: process.h 523 2004-08-20 20:35:27Z aquamaniac $
     begin       : Sat Dec 27 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
