@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: inetsocket.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: inetsocket.c,v 1.10 2005/04/10 14:19:25 aquamaniac Exp $
+    cvs         : $Id: inetsocket.c 978 2006-02-03 17:41:49Z aquamaniac $
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -856,10 +856,18 @@ GWEN_SOCKETSET *GWEN_SocketSet_new() {
 
 
 
+GWEN_SOCKET *GWEN_Socket_fromFile(int fd) {
+  DBG_ERROR(GWEN_LOGDOMAIN,
+            "No file sockets available for this system");
+  return 0;
+}
+
+
+
 void GWEN_SocketSet_free(GWEN_SOCKETSET *ssp) {
   if (ssp) {
     FD_ZERO(&(ssp->set));
-    free(ssp);
+    GWEN_FREE_OBJECT(ssp);
   }
 }
 
@@ -925,8 +933,9 @@ GWEN_SOCKET *GWEN_Socket_new(GWEN_SOCKETTYPE socketType){
 
 
 void GWEN_Socket_free(GWEN_SOCKET *sp){
-  if (sp)
-    free(sp);
+  if (sp) {
+    GWEN_FREE_OBJECT(sp);
+  }
 }
 
 
