@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: inetsocket_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: inetsocket_p.h,v 1.3 2004/03/12 15:22:27 aquamaniac Exp $
+    cvs         : $Id: inetsocket_p.h 266 2004-03-12 15:22:28Z aquamaniac $
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
