@@ -177,16 +177,16 @@ GWEN_ERRORCODE GWEN_LibLoader_Resolve(GWEN_LIBLOADER *h,
                           GWEN_ERROR_SEVERITY_ERR,
                           GWEN_Error_FindType(GWEN_LIBLOADER_ERROR_TYPE),
                           GWEN_LIBLOADER_ERROR_NOT_OPEN);
-  *p=(void*)GetProcAddress((HINSTANCE)h->handle,name);
+  *p=(void*)GetProcAddress((HINSTANCE)h->handle, name);
   if (!*p) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Error resolving symbol \"%s\"\n",
+    DBG_ERROR(GWEN_LOGDOMAIN, "Error resolving symbol \"%s\"",
               name);
     return GWEN_Error_new(0,
                           GWEN_ERROR_SEVERITY_ERR,
                           GWEN_Error_FindType(GWEN_LIBLOADER_ERROR_TYPE),
                           GWEN_LIBLOADER_ERROR_COULD_NOT_RESOLVE);
   }
-  DBG_VERBOUS(GWEN_LOGDOMAIN, "Resolved symbol \"%s\": %08x\n",
+  DBG_VERBOUS(GWEN_LOGDOMAIN, "Resolved symbol \"%s\": %08x",
 	      name, (int)*p);
   return 0;
 }
