@@ -1,7 +1,7 @@
 /***************************************************************************
-  $RCSfile: process.c,v $
+  $RCSfile$
                              -------------------
-    cvs         : $Id: process.c,v 1.5 2004/08/20 09:17:28 aquamaniac Exp $
+    cvs         : $Id: process.c 957 2005-12-23 01:43:18Z aquamaniac $
     begin       : Sun Dec 28 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -74,7 +74,7 @@ void GWEN_Process_free(GWEN_PROCESS *pr){
     GWEN_BufferedIO_free(pr->stdIn);
     GWEN_BufferedIO_free(pr->stdOut);
     GWEN_BufferedIO_free(pr->stdErr);
-    free(pr);
+    GWEN_FREE_OBJECT(pr);
   }
 }
 
