@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: db_p.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: db_p.h,v 1.16 2005/08/22 23:10:45 aquamaniac Exp $
+ cvs         : $Id: db_p.h 844 2005-08-22 23:10:45Z aquamaniac $
  begin       : Tue Sep 09 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
