@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: msgengine.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: msgengine.h,v 1.26 2004/08/09 13:13:58 cstim Exp $
+ cvs         : $Id: msgengine.h 499 2004-08-09 13:13:58Z cstim $
  begin       : Fri Jul 04 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
