@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: msgengine_p.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: msgengine_p.h,v 1.27 2005/07/27 09:23:37 aquamaniac Exp $
+ cvs         : $Id: msgengine_p.h 802 2005-07-27 09:23:37Z aquamaniac $
  begin       : Fri Jul 04 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
