@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: text.h 705 2005-02-23 02:16:57Z aquamaniac $
+ cvs         : $Id: text.h 1043 2006-05-04 20:54:17Z martin $
  begin       : Sat Jun 28 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -100,6 +100,29 @@ char *GWEN_Text_Unescape(const char *src,
                          char *buffer,
                          unsigned int maxsize);
 
+GWENHYWFAR_API
+char *GWEN_Text_UnescapeN(const char *src,
+			  unsigned int srclen,
+                          char *buffer,
+                          unsigned int maxsize);
+
+GWENHYWFAR_API
+char *GWEN_Text_EscapeTolerant(const char *src,
+			       char *buffer,
+			       unsigned int maxsize);
+
+GWENHYWFAR_API
+char *GWEN_Text_UnescapeTolerant(const char *src,
+				 char *buffer,
+				 unsigned int maxsize);
+
+GWENHYWFAR_API
+char *GWEN_Text_UnescapeTolerantN(const char *src,
+				  unsigned int srclen,
+				  char *buffer,
+				  unsigned int maxsize);
+
+
 GWENHYWFAR_API
 int GWEN_Text_EscapeToBuffer(const char *src, GWEN_BUFFER *buf);
 
