@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: xml.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: xml.h,v 1.36 2005/08/04 04:55:47 aquamaniac Exp $
+ cvs         : $Id: xml.h 1000 2006-03-15 11:22:48Z aquamaniac $
  begin       : Sat Jun 28 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -151,6 +151,7 @@ typedef enum {
  * GWEN_XMLNODE_TYPE. */
 typedef struct GWEN__XMLNODE GWEN_XMLNODE;
 
+GWEN_LIST_FUNCTION_LIB_DEFS(GWEN_XMLNODE, GWEN_XMLNode, GWENHYWFAR_API)
 GWEN_LIST2_FUNCTION_LIB_DEFS(GWEN_XMLNODE, GWEN_XMLNode, GWENHYWFAR_API)
 
 
