@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: cryptmanager_l.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: cryptmanager_l.h,v 1.1 2005/07/23 09:39:42 aquamaniac Exp $
+ cvs         : $Id: cryptmanager_l.h 791 2005-07-23 09:39:42Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
