@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: globals.h,v $
+ $RCSfile$
  -------------------
- cvs         : $Id: globals.h,v 1.6 2005/08/24 11:56:24 aquamaniac Exp $
+ cvs         : $Id: globals.h 923 2005-11-19 03:35:10Z aquamaniac $
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -30,8 +30,7 @@
 
 #define GCT_LOGDOMAIN "gct-tool"
 
-
-#define I18N(x) x
+#include "src/base/i18n_l.h"
 
 
 int signFiles(GWEN_DB_NODE *dbArgs, int argc, char **argv);
